@@ -1,4 +1,3 @@
-
 #' Applies the text styles
 #'
 #' @description
@@ -12,23 +11,24 @@
 #' @importFrom openxlsx2 wb_color
 #'
 wb_apply_text_styles <- function(wb, sheet, df_style) {
-
   wb$validate_sheet(sheet)
 
   ## aggregate borders
   df_text_styles <- df_style |>
-    dplyr::select(dplyr::all_of(c("col_id",
-                                  "row_id",
-                                  "font.family",
-                                  "color",
-                                  "font.size",
-                                  "bold",
-                                  "italic",
-                                  "underlined")))
+    dplyr::select(dplyr::all_of(c(
+      "col_id",
+      "row_id",
+      "font.family",
+      "color",
+      "font.size",
+      "bold",
+      "italic",
+      "underlined"
+    )))
 
   df_text_styles_aggregated <- get_dim_ranges(df_text_styles)
 
-  for(i in seq_len(nrow(df_text_styles_aggregated))) {
+  for (i in seq_len(nrow(df_text_styles_aggregated))) {
     crow <- df_text_styles_aggregated[i, ]
 
     wb$add_font(
