@@ -4,11 +4,14 @@ test_that("option string_num is supported", {
 
   ft <- flextable(airquality[seq_len(10), ])
   ft <- add_header_row(ft,
-                       colwidths = c(4, 2),
-                       values = c("Air quality", "Time")
+    colwidths = c(4, 2),
+    values = c("Air quality", "Time")
   )
   ft <- theme_vanilla(ft)
-  ft <- add_footer_lines(ft, "Daily air quality measurements in New York, May to September 1973.")
+  ft <- add_footer_lines(
+    ft,
+    "Daily air quality measurements in New York, May to September 1973."
+  )
   ft <- color(ft, part = "footer", color = "#666666")
   ft <- set_caption(ft, caption = "New York Air Quality Measurements")
   ft
@@ -27,8 +30,7 @@ test_that("option string_num is supported", {
   cc <- wb$worksheets[[2]]$sheet_data$cc
   expect_equal(cc[cc$r == "C5", "v"], "41")
 
-  test_wb_ft(wb,ft, "string_num")
+  test_wb_ft(wb, ft, "string_num")
 
   options("openxlsx2.string_nums" = NULL)
-
 })
